@@ -1,3 +1,5 @@
+from math import ceil
+from typing import Optional
 import django_filters as filters
 from django.core.exceptions import ImproperlyConfigured
 from django.test import TestCase
@@ -60,7 +62,7 @@ class SingleTableViewTest(TestCase):
     def test_should_support_default_pagination(self):
         total_records = 50
         for i in range(1, total_records + 1):
-            Region.objects.create(name="region {:02d} / {}".format(i, total_records))
+            Region.objects.create(name=f"region {i:02d} / {total_records}")
 
         expected_per_page = 25
 
@@ -83,8 +85,8 @@ class SingleTableViewTest(TestCase):
 
         # in addition to New South Wales, Queensland, Tasmania and Victoria,
         # 21 records should be displayed.
-        self.assertContains(response, "21 / {}".format(total_records))
-        self.assertNotContains(response, "22 / {}".format(total_records))
+        self.assertContains(response, f"21 / {total_records}")
+        self.assertNotContains(response, f"22 / {total_records}")
 
     def test_should_support_default_pagination_with_table_options(self):
         class Table(tables.Table):
@@ -175,6 +177,33 @@ class SingleTableViewTest(TestCase):
         self.assertIsInstance(paginator, tables.LazyPaginator)
         self.assertEqual(paginator.orphans, 10)
 
+    def test_get_paginate_by_has_priority_over_paginate_by(self):
+        class View(tables.SingleTableView):
+            table_class = tables.Table
+            queryset = Region.objects.all()
+            # This paginate_by should be ignored because get_paginated_by is overridden
+            paginate_by = 4
+
+            def get_paginate_by(self, queryset):
+                # Should paginate by 10
+                return 10
+
+        response = View.as_view()(build_request())
+        self.assertEqual(response.context_data["table"].paginator.per_page, 10)
+
+    def test_pass_queryset_to_get_paginate_by(self):
+        # defined in paginator_class
+        class View(tables.SingleTableView):
+            table_class = tables.Table
+            queryset = Region.objects.all()
+
+            def get_paginate_by(self, table_data):
+                # Should split table items into 2 pages
+                return ceil(len(table_data) / 2)
+
+        response = View.as_view()(build_request())
+        self.assertEqual(response.context_data["table"].paginator.num_pages, 2)
+
     def test_should_pass_kwargs_to_table_constructor(self):
         class PassKwargsView(SimpleView):
             table_data = []
@@ -203,7 +232,7 @@ class SingleTableViewTest(TestCase):
             def get_table_pagination(self, table):
                 assert isinstance(table, tables.Table)
 
-                per_page = self.request.GET.get("%s_override" % table.prefixed_per_page_field)
+                per_page = self.request.GET.get(f"{table.prefixed_per_page_field}_override")
                 if per_page is not None:
                     return {"per_page": per_page}
                 return super().get_table_pagination(table)
@@ -252,12 +281,13 @@ class SingleTableViewTest(TestCase):
         self.assertEqual(table_class.__name__, "RegionAutogeneratedTable")
 
     def test_get_tables_class_raises_no_model(self):
-        class SimpleNoTableClassNoModelView(tables.SingleTableView):
+        class Table(tables.SingleTableView):
             model = None
             table_class = None
 
-        view = SimpleNoTableClassNoModelView()
-        with self.assertRaises(ImproperlyConfigured):
+        view = Table()
+        message = "You must either specify Table.table_class or Table.model"
+        with self.assertRaisesMessage(ImproperlyConfigured, message):
             view.get_table_class()
 
 
@@ -288,7 +318,7 @@ class SingleTableMixinTest(TestCase):
 
         total_records = 60
         for i in range(1, total_records + 1):
-            Region.objects.create(name="region {i:02d} / {total_records}".format(**locals()))
+            Region.objects.create(name=f"region {i:02d} / {total_records}")
 
         expected_per_page = 25
 
@@ -381,7 +411,8 @@ class MultiTableMixinTest(TestCase):
         class View(tables.MultiTableMixin, TemplateView):
             template_name = "multiple.html"
 
-        with self.assertRaises(ImproperlyConfigured):
+        message = "No tables were specified. Define View.tables"
+        with self.assertRaisesMessage(ImproperlyConfigured, message):
             View.as_view()(build_request("/"))
 
     def test_with_empty_get_tables_list(self):
@@ -414,7 +445,8 @@ class MultiTableMixinTest(TestCase):
             tables_data = (Person.objects.all(),)
             template_name = "multiple.html"
 
-        with self.assertRaises(ImproperlyConfigured):
+        message = "len(View.tables_data) != len(View.tables)"
+        with self.assertRaisesMessage(ImproperlyConfigured, message):
             View.as_view()(build_request("/"))
 
     def test_table_pagination(self):
@@ -443,6 +475,21 @@ class MultiTableMixinTest(TestCase):
         self.assertEqual(tableA.page.number, 1)
         self.assertEqual(tableB.page.number, 3)
 
+    def test_pass_table_data_to_get_paginate_by(self):
+        class View(tables.MultiTableMixin, TemplateView):
+            template_name = "multiple.html"
+            tables = (TableB, TableB)
+            tables_data = (Region.objects.all(), Region.objects.all())
+
+            def get_paginate_by(self, table_data) -> Optional[int]:
+                # Split data into 3 pages
+                return ceil(len(table_data) / 3)
+
+        response = View.as_view()(build_request())
+
+        for table in response.context_data["tables"]:
+            self.assertEqual(table.paginator.num_pages, 3)
+
     def test_get_tables_data(self):
         class View(tables.MultiTableMixin, TemplateView):
             tables = (TableA, TableB)
